@@ -15,10 +15,10 @@
 //!
 //! Add these dependencies to your `Cargo.toml` file.
 //!
-//! ```
+//! ```toml
 //! [dependencies]
-//! hyper-reverse-proxy = "0.3.0"
-//! hyper = "0.12.24"
+//! hyper-reverse-proxy = "0.4"
+//! hyper = "0.12"
 //! futures = "0.1"
 //! ```
 //!
@@ -32,10 +32,6 @@
 //! * All other URLs will be handled by `debug_request` function, that will display request information.
 //!
 //! ```rust,no_run
-//! extern crate hyper;
-//! extern crate hyper_reverse_proxy;
-//! extern crate futures;
-//!
 //! use hyper::server::conn::AddrStream;
 //! use hyper::{Body, Request, Response, Server};
 //! use hyper::service::{service_fn, make_service_fn};
@@ -54,17 +50,21 @@
 //!     // This is our socket address...
 //!     let addr = ([127, 0, 0, 1], 13900).into();
 //!
-//!     // A `Service` is needed for every connection, so this
-//!     // creates one from our `hello_world` function.
+//!     // A `Service` is needed for every connection.
 //!     let make_svc = make_service_fn(|socket: &AddrStream| {
 //!         let remote_addr = socket.remote_addr();
 //!         service_fn(move |req: Request<Body>| { // returns BoxFut
 //!
-//!             // Auth
 //!             if req.uri().path().starts_with("/target/first") {
+//!
+//!                 // will forward requests to port 13901
 //!                 return hyper_reverse_proxy::call(remote_addr.ip(), "http://127.0.0.1:13901", req)
+//!
 //!             } else if req.uri().path().starts_with("/target/second") {
+//!
+//!                 // will forward requests to port 13902
 //!                 return hyper_reverse_proxy::call(remote_addr.ip(), "http://127.0.0.1:13902", req)
+//!
 //!             } else {
 //!                 debug_request(req)
 //!             }
@@ -83,11 +83,6 @@
 //! ```
 //!
 
-extern crate hyper;
-extern crate futures;
-extern crate lazy_static;
-extern crate unicase;
-
 use hyper::Body;
 use std::net::IpAddr;
 use std::str::FromStr;
